

resolver(3N)                                            resolver(3N)


NAME
      resolver, res_mkquery, res_send, res_init, dn_comp, dn_expand
      - resolver routines

SYNOPSIS
      cc [options] file -lresolv -lsocket -lnsl
      #include <sys/types.h>
      #include <netinet/in.h>
      #include <arpa/nameser.h>
      #include <resolv.h>
      int res_mkquery(int op, char *dname, int class, int type,
          char *data, int datalen, struct rrec *newrr, char *buf,
          int buflen);
      int res_send(char *buf, int buflen, char *answer, int anslen);
      int res_init(void);
      int dn_comp(u_char *exp_dn, u_char *comp_dn, int length, u_char **dnptrs,
          u_char **lastdnptr);
      int dn_expand(u_char *msg, u_char *eomorig, u_char *comp_dn,
          u_char *exp_dn, int length);

DESCRIPTION
     These routines are used for making, sending and interpreting
     packets to Internet domain name servers.  Global information
     that is used by the resolver routines is kept in the variable
     _res.  Most of the values have reasonable defaults and can be
     ignored.  Options are a simple bit mask and are OR'ed in to
     enable.  Options stored in _res.options are defined in
     resolv.h and are as follows.

     RES_INIT            True if the initial name server address
                         and default domain name are initialized
                         (that is, res_init has been called).

     RES_DEBUG           Print debugging messages.

     RES_AAONLY          Accept authoritative answers only.
                         res_send will continue until it finds an
                         authoritative answer or finds an error.
                         Currently this is not implemented.

     RES_USEVC           Use TCP connections for queries instead of
                         UDP.

     RES_STAYOPEN        Used with RES_USEVC to keep the TCP
                         connection open between queries.  This is
                         useful only in programs that regularly do
                         many queries.  UDP should be the normal
                         mode used.

     RES_IGNTC           Unused currently (ignore truncation
                         errors, that is, do not retry with TCP).

     RES_RECURSE         Set the recursion desired bit in queries.
                         This is the default.  res_send does not do
                         iterative queries and expects the name
                         server to handle recursion.

     RES_DEFNAMES        Append the default domain name to single
                         label queries.  This is the default.

     RES_DNSRCH          Allow search for a domain name up the
                         local hierarchical domain tree.

     res_init reads the initialization file to get the default
     domain name and the Internet address of the initial hosts
     running the name server.  If this line does not exist, the
     host running the resolver is tried.  res_init returns 0 for
     success, and -1 for failure.  res_mkquery makes a standard
     query message and places it in buf.  res_mkquery will return
     the size of the query or -1 if the query is larger than
     buflen.  op is usually QUERY but can be any of the query types
     defined in arpa/nameser.h.  dname is the domain name.  If
     dname consists of a single label and the RES_DEFNAMES flag is
     enabled (the default), dname will be appended with the current
     domain name.  The current domain name is defined in a system
     file and can be overridden by the environment variable
     LOCALDOMAIN.  newrr is currently unused but is intended for
     making update messages.

     res_send sends a query to name servers and returns an answer.
     It will call res_init if RES_INIT is not set, send the query
     to the local name server, and handle timeouts and retries.
     The length of the message is returned or -1 if there were
     errors.

     dn_expand expands the compressed domain name comp_dn to a full
     domain name.  Expanded names are converted to upper case.  msg
     is a pointer to the beginning of the message, eomorig is a
     pointer to the first memory location after the message, exp_dn
     is a pointer to a buffer of size length for the result.  The
     size of the compressed name is returned or -1 if there was an
     error.

     dn_comp compresses the domain name exp_dn and stores it in
     comp_dn.  The size of the compressed name is returned or -1 if
     there were errors.  length is the size of the array pointed to
     by comp_dn.  dnptrs is a list of pointers to previously
     compressed names in the current message.  The first pointer
     points to the beginning of the message and the list ends with
     NULL.  lastdnptr is a pointer to the end of the array pointed
     to dnptrs.  A side effect is to update the list of pointers
     for labels inserted into the message by dn_comp as the name is
     compressed.  If dnptr is NULL, do not try to compress names.
     If lastdnptr is NULL, do not update the list.

  Files
     /etc/resolv.conf
     /usr/include/arpa/nameserv.h
     /usr/include/netinet/in.h
     /usr/include/resolv.h
     /usr/include/sys/types.h
     /usr/lib/libresolv.a
     /usr/lib/resolv.so

REFERENCES
     named(1M), resolv.conf(4)

NOTICES
     /usr/lib/libresolv.a is necessary for compiling programs.
     Programs must be loaded with the option -lresolv.

============================================================================


resolv.conf(4)                                        resolv.conf(4)


NAME
      resolv.conf - configuration file for name server routines

SYNOPSIS
      /etc/resolv.conf

DESCRIPTION
      The resolver configuration file resolv.conf contains
      information that is read by the resolver routines the first
      time they are invoked in a process.

USAGE
      The resolv.conf file is designed to be human-readable, and
      contains a list of keyword-value pairs that provide various
      types of resolver information.

      Each keyword-value pair must appear on a single line.  Each
      line must start with a keyword (for example, nameserver) The
      value must follow the keyword, separated by white space:

            keyword value

      The different configuration options are:

      nameserver address  Specifies the Internet address (in dot
                          notation) of a name server that the
                          resolver should query.

                          At least one name server should be listed.
                          Up to MAXNS (currently 3) name servers may
                          be listed; the resolver library queries
                          will query the servers in the order
                          listed.  The algorithm used is to try a
                          name server, and if the query times out,
                          try the next, until out of name servers,
                          then repeat trying all the name servers
                          until a maximum number of retries are
                          made.

      domain name         Specifies the default domain to append to
                          names that do not have a dot in them.

REFERENCES
      gethostent(3N), named(1M), resolver(3N)


=====================================================================


NAME
      named - Internet domain name server

SYNOPSIS
      in.named [-d level] [-p port] [[-b] bootfile]

DESCRIPTION
      The named command is the Internet domain name server.  It is
      used by hosts on the Internet to provide access to the
      Internet distributed naming data base.  See RFC 1034 and RFC
      1035 for more details.

   Files
      /etc/named.boot               name server configuration boot
                                    file
      /etc/named.pid                the process ID
      /var/tmp/named.run            debug output
      /var/tmp/named_dump.db        dump of the name servers data
                                    base
      /var/tmp/named.stats          nameserver statistics data

USAGE
      With no arguments, named reads /etc/named.boot for any initial
      data, and listens for queries on a privileged port.

   Options
      named takes the following options:

      -d level    print debugging information.  level is a number
                  indicating the level of messages printed.  level
                  is a number from 1 to 9.  Higher numbers give more
                  detailed debugging information.

      -p port     use a different port number.  The default is the
                  standard port number as listed in /etc/services.

      -b bootfile use bootfile rather than /etc/named.boot.  This is
                  optional and allows you to specify a file with a
                  leading dash.

      Any additional arguments are taken as the name of the
      bootfile.  The bootfile contains information about where the
      name server is to get its initial data.  If multiple bootfiles
      are specified, only the last is used.  Lines in the bootfile
      cannot be continued on subsequent lines.  Note that all domain
      names in the bootfile must not contain a trailing ``.'' (dot).


  Examples
     The following is a sample boot file for a name server.
     ;
     ;boot file for name server
     ;
     directory   /usr/lib/named
     ; type  domain           source host/filebackup file
     cache   .                            root.cache
     primary Berkeley.EDU     berkeley.edu.zone
     primary 32.128.IN-ADDR.ARPA          ucbhosts.rev
     secondary                CC.Berkeley.EDU 128.32.137.8 128.32.137.3cc.zone.bak
     secondary                6.32.128.IN-ADDR.ARPA 128.32.137.8 128.32.137.3cc.rev.bak
     primary 0.0.127.IN-ADDR.ARPA         localhost.rev
     forwarders               10.0.0.78 10.2.0.78
     ; slave

     In the example, the directory line causes the server to change
     its working directory to the directory specified.  This can be
     important for the correct processing of $INCLUDE files in
     primary zone files.

     The cache line specifies that data in root.cache is to be
     placed in the backup cache.  Its main use is to specify data
     such as locations of root domain servers.  This cache is not
     used during normal operation, but is used as hints to find the
     current root servers.  The file root.cache is in the same
     format as berkeley.edu.zone.  There can be more than one cache
     file specified.  The cache files are processed in such a way
     as to preserve the time-to-live's of data dumped out.  Data
     for the root nameservers is kept artificially valid if
     necessary.

     The first primary line states that the file berkeley.edu.zone
     contains authoritative data for the Berkeley.EDU zone.  The
     file berkeley.edu.zone contains data in the master file format
     described in RFC1035.  All domain names are relative to the
     origin, in this case, Berkeley.EDU (see below for a more
     detailed description).  The second primary line states that
     the file ucbhosts.rev contains case, Berkeley.EDU (see below
     for a more detailed description).  The second primary line
     states that the file ucbhosts.rev contains authoritative data
     for the domain 32.128.IN-ADDR.ARPA, which is used to translate
     addresses in network 128.32 to hostnames.  Each master file
     should begin with an SOA record for the zone (see below).

     The first secondary line specifies that all authoritative data
     under CC.Berkeley.EDU is to be transferred from the name
     server at 128.32.137.8.  If the transfer fails it will try
     128.32.137.3 and continue trying the addresses, up to 10,
     listed on this line.  The secondary copy is also authoritative
     for the specified domain.  The first non-dotted-quad address
     on this line will be taken as a filename in which to backup
     the transferred zone.  The name server will load the zone from
     this backup file if it exists when it boots, providing a
     complete copy even if the master servers are unreachable.
     Whenever a new copy of the domain is received by automatic
     zone transfer from one of the master servers, this file will
     be updated.  The second secondary line states that the
     address-to-hostname mapping for the subnet 128.32.136 should
     be obtained from the same list of master servers as the
     previous zone.

     The forwarders line specifies the addresses of sitewide
     servers that will accept recursive queries from other servers.
     If the boot file specifies one or more forwarders, then the
     server will send all queries for data not in the cache to the
     forwarders first.  Each forwarder will be asked in turn until
     an answer is returned or the list is exhausted.  If no answer
     is forthcoming from a forwarder, the server will continue as
     it would have without the forwarders line unless it is in
     slave mode.  The forwarding facility is useful to cause a
     large sitewide cache to be generated on a master, and to
     reduce traffic over links to outside servers.  It can also be
     used to allow servers to run that do not have access directly
     to the Internet, but wish to act as though they do.

     The slave line (shown commented out) is used to put the server
     in slave mode.  In this mode, the server will only make
     queries to forwarders.  This option is normally used on
     machine that wish to run a server but for physical or
     administrative reasons cannot be given access to the Internet,
     but have access to a host that does have access.

     The sortlist line can be used to indicate networks that are to
     be preferred over other, unlisted networks.  Queries for host
     addresses from hosts on the same network as the server will
     receive responses with local network addresses listed first,
     then addresses on the sort list, then other addresses.  This
     line is only acted on at initial startup.  When reloading the
     nameserver with a SIGHUP, this line will be ignored.

  Master File
     The master file consists of control information and a list of
     resource records for objects in the zone of the forms:
           $INCLUDE < filename >
           $ORIGIN < domain >
           < domain > < opt_ttl > < opt_class > < type >
           < resource_record_data >

     where domain is . for the root, @ for the current origin, or a
     standard domain name.  If domain is a standard domain name
     that does not end with ., the current origin is appended to
     the domain.  Domain names ending with . are unmodified.  When
     you need to specify a fully qualified domain name (such as
     somehost.berkeley.edu.), be sure to include the trailing ``.''
     (dot).

     The opt_ttl field is an optional integer number for the time-
     to-live field.  It defaults to zero.

     The opt_class field is currently one token, IN for the
     Internet.

     The type field is one of the following tokens; the data
     expected in the resource_record_data field is in parentheses.

     A           A host address (dotted quad).

     NS          An authoritative name server (domain).

     MX          A mail exchanger (domain).

     CNAME       The canonical name for an alias (domain).

     SOA         Marks the start of a zone of authority (5 numbers:
                 domain of originating host, domain address of
                 maintainer, a serial number and the following
                 parameters in seconds: refresh, retry, expire and
                 minimum TTL).  See RFC 1035.

     MB          A mailbox domain name (domain).

     MG          A mail group member (domain).

     MR          A mail rename domain name (domain).

     NULL        A null resource record (no format or data).

     WKS         A well know service description (not implemented
                 yet).

     PTR         A domain name pointer (domain).

     HINFO       Host information (cpu_type OS_type).

     MINFO       Mailbox or mail list information (request_domain
                 error_domain).

     Resource records normally end at the end of a line, but may be
     continued across lines between opening and closing
     parentheses.  Comments are introduced by semicolons and
     continue to the end of the line.

     Each master zone file should begin with an SOA record for the
     zone.  An example SOA record is as follows:

          IN     SOA     ucbvax.Berkeley.EDU.   rwh.ucbvax.Berkeley.EDU. (
                                     2.89    ; serial
                                     10800   ; refresh
                                     3600    ; retry
                                     3600000 ; expire
                                     86400 ) ; minimum

     The SOA lists a serial number, which should be changed each
     time the master file is changed.  Secondary servers check the
     serial number at intervals specified by the refresh file is
     changed.  Secondary servers check the serial number at
     intervals specified by the refresh time in seconds; if the
     serial number changes, a zone transfer will be done to load
     the new data.  If a master server cannot be contacted when a
     refresh is due, the retry time specifies the interval at which
     refreshes should be attempted until successful.  If a master
     server cannot be contacted within the interval given by the
     expire time, all data from the zone is discarded by secondary
     servers.  The minimum value is the time-to-live used by
     records in the file with no explicit time-to-live value.

   Signals
     The following signals have the specified effect when sent to
     the server process using the kill(1) command.

     SIGHUP          Causes server to read named.boot and reload
                     data base.

     SIGINT          Dumps current data base and cache to
                     /var/tmp/named_dump.db.

     SIGIOT          Dumps statistics data into
                     /var/tmp/named.stats if the server is compiled
                     -DSTATS.  Statistics data is appended to the
                     file.

     SIGSYS          Dumps the profiling data in /var/tmp if the
                     server is compiled with profiling (server
                     forks, chdirs and exits).

     SIGTERM         Dumps the primary and secondary data base
                     files.  Used to save modified data on shutdown
                     if the server is compiled with dynamic
                     updating enabled.

     SIGUSR1         Turns on debugging; each SIGUSR1 increments
                     debug level.

     SIGUSR2         Turns off debugging completely.

  Warnings
     The boot file directives domain and suffixes have been
     obsoleted by a more useful resolver based implementation of
     suffixing for partially qualified domain names.  The prior
     mechanisms could fail under a number of situations, especially
     when then local nameserver did not have complete information.

REFERENCES
     hostname(5), kill(1), resolv.conf(4), resolver(3N), signal(2),
     signal(3BSD)
     RFC 973, RFC 974, RFC 1034, RFC 1035
